/*
 * Name:    sq_apsid.h
 *
 * Purpose: Header file for quick scans that use an MX MCS to collect the data
 *          and simultaneously synchronously scan an Advanced Photon Source
 *          insertion device.  This scan type is a variant of the MCS quick
 *          scan and uses most of the same code.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2000 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __SQ_APSID_H__
#define __SQ_APSID_H__

typedef struct {
	MX_RECORD *id_ev_record;
	int id_ev_harmonic;
	double id_ev_offset;
} MX_APSID_QUICK_SCAN_EXTENSION;

MX_API mx_status_type mxs_apsid_quick_scan_prepare_for_scan_start(
							MX_SCAN *scan );
MX_API mx_status_type mxs_apsid_quick_scan_execute_scan_body(
							MX_SCAN *scan );
MX_API mx_status_type mxs_apsid_quick_scan_cleanup_after_scan_end(
							MX_SCAN *scan );

extern MX_RECORD_FUNCTION_LIST mxs_apsid_quick_scan_record_function_list;
extern MX_SCAN_FUNCTION_LIST mxs_apsid_quick_scan_scan_function_list;

extern long mxs_apsid_quick_scan_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxs_apsid_quick_scan_def_ptr;

#endif /* __SQ_APSID_H__ */

